@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::Timing;
-$Test::Class::Moose::Role::Timing::VERSION = '0.51';
+$Test::Class::Moose::Role::Timing::VERSION = '0.52';
 # ABSTRACT: Report timing role
 
 use Moose::Role;
@@ -43,42 +43,4 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
-=head1 NAME
-
-Test::Class::Moose::Role::Timing - Report timing role
-
-=head1 VERSION
-
-version 0.51
-
-=head1 DESCRIPTION
-
-Note that everything in here is experimental and subject to change.
-
-=head1 REQUIRES
-
-None.
-
-=head1 PROVIDED
-
-=head1 ATTRIBUTES
-
-=head2 C<time>
-
-Returns a L<Test::Class::Moose::Report::Time> object. This object
-represents the duration of this class or method.
-
-=head1 AUTHOR
-
-Curtis "Ovid" Poe <ovid@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Curtis "Ovid" Poe.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
